@@ -146,7 +146,10 @@ class RegisterWatchList:
 
     # Matches tokens in reverse order
     def try_match_swapped(self, i, line, increment):
-        return self.insts[i + 1].type == self.code[line][1] and self.insts[i].type == self.code[line + 1][1]
+        try:
+            return self.insts[i + 1].type == self.code[line][1] and self.insts[i].type == self.code[line + 1][1]
+        except:
+            return False
 
 # Translates PC values to instructions, for auto captured ISA
 class PCTranslator:
@@ -230,7 +233,7 @@ class PCTranslator:
                 inst_pos += 1
             return self.getcode(self.insts[inst_pos].cycles)[0][-3]
         except:
-            print('SWAPPC warning: Could not find addr', hex(self.insts[inst_index+1].cycles), 'for', inst_index, line)
+            print('SWAPPC warning: Could not find addr for', inst_index, line)
             return -1
     def setpc(self, line, inst_index):
         try:
@@ -239,7 +242,7 @@ class PCTranslator:
                 inst_pos += 1
             return self.getcode(self.insts[inst_pos].cycles)[0][-3]
         except:
-            print('SETPC warning: Could not find addr', hex(self.insts[inst_index+1].cycles), 'for', inst_index, line)
+            print('SETPC warning: Could not find addr for', inst_index, line)
             return -1
     def scratch(self, line):
         pass
@@ -420,24 +423,23 @@ def stitch(insts, raw_code, jumps, gfxv, bIsAuto, codeservice):
                 if "flat_" in as_line[0]:
                     inc_ordering = True
 
-                if not "buffer_" in as_line[0] or not ("_inv" in as_line[0] or "_wb" in as_line[0]):
-                    if not bGFX9 and "store" in as_line[0]:
-                        VSMEM_INST.append([reverse_map[line], num_inflight])
-                        NUM_VSMEM += 1
-                        if inc_ordering:
-                            vsmem_ordering = 1
-                    else:
-                        VLMEM_INST.append([reverse_map[line], num_inflight])
-                        NUM_VLMEM += 1
-                        if inc_ordering:
-                            vlmem_ordering = 1
+                if not bGFX9 and "store" in as_line[0]:
+                    VSMEM_INST.append([reverse_map[line], num_inflight])
+                    NUM_VSMEM += 1
+                    if inc_ordering:
+                        vsmem_ordering = 1
+                else:
+                    VLMEM_INST.append([reverse_map[line], num_inflight])
+                    NUM_VLMEM += 1
+                    if inc_ordering:
+                        vlmem_ordering = 1
             elif inst.type == FLAT:
                 smem_ordering = 1
                 vlmem_ordering = 1
                 vsmem_ordering = 1
                 FLAT_INST.append([reverse_map[line], num_inflight])
                 NUM_FLAT += 1
-            elif inst.type == IMMED and "s_wait" in as_line[0]:
+            elif inst.type == IMMED and "s_wait" in as_line[0] and not "s_wait_alu" in as_line[0]:
                 if "lgkmcnt" in as_line[0] or "dscnt" in as_line[0] or "kmcnt" in as_line[0]:
                     try:
                         wait_N = int(as_line[0].split("lgkmcnt(")[1].split(")")[0])
@@ -521,13 +523,15 @@ def stitch(insts, raw_code, jumps, gfxv, bIsAuto, codeservice):
                 insts[i] = insts[i + 1]
                 insts[i + 1] = temp
                 next = line
-            elif "s_wait" in as_line[0] or "_load_" in as_line[0]:
-                if skipped_immed > 0 and "s_wait" in as_line[0]:
-                    matched = True
-                    skipped_immed -= 1
-                elif 'scratch_' not in as_line[0]:
-                    print('WARNING: Parsing terminated at:', as_line)
-                    break
+            else:
+                hasWait = "s_wait" in as_line[0]
+                if hasWait or "_load_" in as_line[0]:
+                    if skipped_immed > 0 and hasWait:
+                        matched = True
+                        skipped_immed -= 1
+                    elif 's_waitcnt' in as_line[0] and 'scratch_' not in as_line[0]:
+                        print('WARNING: Parsing terminated at:', as_line)
+                        break
 
         if matched or as_line[1] != DONT_KNOW:
             if matched:
@@ -549,7 +553,7 @@ def stitch(insts, raw_code, jumps, gfxv, bIsAuto, codeservice):
         line = next
 
     N = max(N, 1)
-    if i != N and insts[i].type == WAVE_ENDED:
+    if i != N and (insts[i].type == WAVE_ENDED or i == N-1):
         print('Warning - Wave ended.')
     elif i < N:
         print('Warning - Stitching rate: '+str(i * 100 / N)+'% matched', i, ' of ', N)
